/**
 * CARTAGO-JASON-BRIDGE - Developed by aliCE team at deis.unibo.it
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package cartago;

import jason.JasonException;
import jason.asSemantics.TransitionSystem;
import jason.asSemantics.Unifier;
import jason.asSemantics.DefaultInternalAction;
import jason.asSyntax.*;
import c4jason.*;

/**
 * <p>Internal action: <b><code>cartago.callObj</code></b>.</p>
 *
 * <p>Description: invoke a method on a Java object located in the agent private memory [temporary, still to be refined].</p>
 *
 * <p>Parameters:
 * <ul>
 * <li>+ objRef (atom): object reference
 * <li>+ methodSignature (structure or atom): method signature, with actual parameters</li>
 * <li>- <i>result</i> (var [optional]): result
 * </ul></p>
 */
public class invoke_obj extends DefaultInternalAction {
	
	@Override
	public Object execute(TransitionSystem ts, Unifier un, Term[] args) throws Exception {
		CAgentArch agent = ((CAgentArch) ts.getUserAgArch());

		if (args.length != 2 && args.length != 3) {
			throw new JasonException(
					"Invalid number of arguments:  invoke_obj(+ObjRef,+Signature{,-Result})");
		}

		Term objId = null;
		if (args[0] instanceof VarTerm) {
			VarTerm objIdvar = (VarTerm)args[0];
			if (objIdvar.isGround() && objIdvar.isAtom()){
				objId = objIdvar.getValue();
			} else {
				throw new JasonException("Invalid obj ref: "+args[0]);
			}		
		} else if (!args[0].isAtom() && !args[0].isString()){
			throw new JasonException("Invalid obj ref: "+args[0]);
		} else {
			objId = args[0];
		}
		
		if (!args[1].isAtom() && !args[1].isStructure() && !args[1].isString()){
			throw new JasonException("Invalid method signature: "+args[1]);
		}
		VarTerm idResult = null;
		if (args.length > 2){
			if (!args[2].isVar()){
				throw new JasonException("Invalid result variable: "+args[2]);
			}
			idResult = (VarTerm)args[2];
		}
		return agent.getJavaLib().java_call(un, objId, args[1], idResult);
	}
}

